<?php

declare(strict_types=1);

namespace Tricks\NovaTools\Nova\Fields;

use Tricks\NovaTools\Traits\StoresMediaLibrary;

final class File extends \Laravel\Nova\Fields\File
{
    use StoresMediaLibrary;

    public $deletable = false;

    public function __construct(
        string $name,
        string $attribute,
    ) {
        parent::__construct($name, $attribute);

        $this->initMediaLibrary();
    }
}
