<?php

declare(strict_types=1);

return [
    'frontend' => [
        /** @phpstan-ignore larastan.noEnvCallsOutsideOfConfig */
        'url' => env('BASE_URL'),
    ],

    'preview_mapping' => [
        // \App\Models\User::class => 'benutzer',
    ],
];
